@@ -77,9 +77,8 @@ where
             );
             *n = Expr::Lit(Lit::Str(Str {
                 span,
+                raw: None,
                 value: value.into(),
-                has_escape: false,
-                kind: Default::default(),
             }));
             return;
         }
@@ -93,11 +92,12 @@ where
                     v.value
                 );
 
+                let value = format!("{:?}", v.value);
+
                 *n = Expr::Lit(Lit::Str(Str {
                     span: v.span,
-                    value: format!("{:?}", v.value).into(),
-                    has_escape: false,
-                    kind: Default::default(),
+                    raw: None,
+                    value: value.into(),
                 }));
             }
 
@@ -112,11 +112,12 @@ where
                     v.flags
                 );
 
+                let value = format!("/{}/{}", v.exp, v.flags);
+
                 *n = Expr::Lit(Lit::Str(Str {
                     span: v.span,
-                    value: format!("/{}/{}", v.exp, v.flags).into(),
-                    has_escape: false,
-                    kind: Default::default(),
+                    raw: None,
+                    value: value.into(),
                 }));
             }
 
@@ -141,9 +142,8 @@ where
 
                     *n = Expr::Lit(Lit::Str(Str {
                         span: i.span,
+                        raw: None,
                         value: js_word!("undefined"),
-                        has_escape: false,
-                        kind: Default::default(),
                     }));
                 }
             }
